@@ -1,7 +1,7 @@
 <?php
 
 /*
- *  $Id: 9cb68248121b72e0921582078ba48eb02f994006 $
+ *  $Id: af7509719aa6a6d1276e8640587764ccd9e5baf2 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -38,7 +38,7 @@ include_once 'phing/parser/CustomChildCreator.php';
  * @author    Andreas Aderhold <andi@binarycloud.com>
  * @author    Hans Lellelid <hans@xmpl.org>
  * @copyright 2001,2002 THYRELL. All rights reserved
- * @version   $Id: 9cb68248121b72e0921582078ba48eb02f994006 $
+ * @version   $Id: af7509719aa6a6d1276e8640587764ccd9e5baf2 $
  * @package   phing
  */
 class IntrospectionHelper
@@ -472,6 +472,10 @@ class IntrospectionHelper
                     $nestedElement = new $classname();
                 }
 
+                if ($nestedElement instanceof Task && $element instanceof Task) {
+                    $nestedElement->setOwningTarget($element->getOwningTarget());
+                }
+
                 $method->invoke($element, $nestedElement);
 
             } catch (Exception $exc) {
