@@ -4,7 +4,7 @@
  * This is the Phing command line launcher. It starts up the system evironment
  * tests for all important paths and properties and kicks of the main command-
  * line entry point of phing located in phing.Phing
- * @version $Id: 2360f2e622d688e063ade814b221dca4b6859d34 $
+ * @version $Id: e414c24b4fc34b7949bc762e9314750a83eea86b $
  */
 
 // Use composers autoload.php if available
@@ -39,8 +39,7 @@ function hasColorSupport()
 
 // default logger
 if (!in_array('-logger', $argv) && hasColorSupport()) {
-    $argv[] = '-logger';
-    $argv[] = 'phing.listener.AnsiColorLogger';
+    array_splice($argv, 1, 0, array('-logger', 'phing.listener.AnsiColorLogger'));
 }
 
 try {
