@@ -1,8 +1,5 @@
 <?php
-
-/* 
- *  $Id: bc979767c07b19eafeb3fc6f6efa938dd73bde18 $
- *
+/**
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
@@ -17,7 +14,7 @@
  *
  * This software consists of voluntary contributions made by many individuals
  * and is licensed under the LGPL. For more information please see
- * <http://phing.info>. 
+ * <http://phing.info>.
  */
 
 /**
@@ -32,66 +29,69 @@
  * FIXME:
  *  - Error handling reduced to min fallthrough runtime exceptions
  *    more precise errorhandling is done by the PhingFile class
- *    
+ *
  * @author Charlie Killian <charlie@tizac.com>
  * @author Hans Lellelid <hans@xmpl.org>
- * @version $Id: bc979767c07b19eafeb3fc6f6efa938dd73bde18 $
+ *
  * @package phing.system.io
  */
-abstract class FileSystem {    
+abstract class FileSystem
+{
 
     /**
      * @var int
      */
-    const BA_EXISTS    = 0x01;
-    
+    const BA_EXISTS = 0x01;
+
     /**
      * @var int
      */
-    const BA_REGULAR   = 0x02;
-    
+    const BA_REGULAR = 0x02;
+
     /**
      * @var int
      */
     const BA_DIRECTORY = 0x04;
-    
+
     /**
      * @var int
      */
-    const BA_HIDDEN    = 0x08;
-    
+    const BA_HIDDEN = 0x08;
+
     /**
      * Instance for getFileSystem() method.
      * @var FileSystem
      */
     private static $fs;
-    
+
     /**
      * Static method to return the FileSystem singelton representing
      * this platform's local filesystem driver.
-     * 
+     *
      * @return FileSystem
      * @throws IOException
      */
-    public static function getFileSystem() {
+    public static function getFileSystem()
+    {
         if (self::$fs === null) {
-            switch(Phing::getProperty('host.fstype')) {
+            switch (Phing::getProperty('host.fstype')) {
                 case 'UNIX':
                     include_once 'phing/system/io/UnixFileSystem.php';
                     self::$fs = new UnixFileSystem();
-                break;
+                    break;
                 case 'WIN32':
                     include_once 'phing/system/io/Win32FileSystem.php';
                     self::$fs = new Win32FileSystem();
-                break;
+                    break;
                 case 'WINNT':
                     include_once 'phing/system/io/WinNTFileSystem.php';
                     self::$fs = new WinNTFileSystem();
-                break;
+                    break;
                 default:
                     throw new IOException("Host uses unsupported filesystem, unable to proceed");
             }
         }
+
         return self::$fs;
     }
 
@@ -100,80 +100,81 @@ abstract class FileSystem {
     /**
      * Return the local filesystem's name-separator character.
      */
-    abstract function getSeparator();
+    abstract public function getSeparator();
 
     /**
      * Return the local filesystem's path-separator character.
      */
-    abstract function getPathSeparator();
+    abstract public function getPathSeparator();
 
     /**
      * Convert the given pathname string to normal form.  If the string is
      * already in normal form then it is simply returned.
-     * 
+     *
      * @param string $strPath
      */
-    abstract function normalize($strPath);
+    abstract public function normalize($strPath);
 
     /**
      * Compute the length of this pathname string's prefix.  The pathname
      * string must be in normal form.
-     * 
+     *
      * @param string $pathname
      */
-    abstract function prefixLength($pathname);
+    abstract public function prefixLength($pathname);
 
     /**
      * Resolve the child pathname string against the parent.
      * Both strings must be in normal form, and the result
      * will be a string in normal form.
-     * 
+     *
      * @param string $parent
      * @param string $child
      */
-    abstract function resolve($parent, $child);
-    
+    abstract public function resolve($parent, $child);
+
     /**
      * Resolve the given abstract pathname into absolute form.  Invoked by the
      * getAbsolutePath and getCanonicalPath methods in the PhingFile class.
-     * 
+     *
      * @param PhingFile $f
      */
-    abstract function resolveFile(PhingFile $f);
+    abstract public function resolveFile(PhingFile $f);
 
     /**
      * Return the parent pathname string to be used when the parent-directory
      * argument in one of the two-argument PhingFile constructors is the empty
      * pathname.
      */
-    abstract function getDefaultParent();
+    abstract public function getDefaultParent();
 
     /**
      * Post-process the given URI path string if necessary.  This is used on
      * win32, e.g., to transform "/c:/foo" into "c:/foo".  The path string
      * still has slash separators; code in the PhingFile class will translate them
      * after this method returns.
-     * 
+     *
      * @param string $path
      */
-    abstract function fromURIPath($path);
-    
+    abstract public function fromURIPath($path);
+
     /* -- Path operations -- */
 
     /**
      * Tell whether or not the given abstract pathname is absolute.
-     * 
+     *
      * @param PhingFile $f
      */
-    abstract function isAbsolute(PhingFile $f);
+    abstract public function isAbsolute(PhingFile $f);
 
-    /** 
-     * canonicalize filename by checking on disk 
-     * @param string $strPath 
-     * @return mixed Canonical path or false if the file doesn't exist.
+    /**
+     * canonicalize filename by checking on disk
+     * @param  string $strPath
+     * @return mixed  Canonical path or false if the file doesn't exist.
      */
-    function canonicalize($strPath) {
-        return @realpath($strPath);        
+    public function canonicalize($strPath)
+    {
+        return @realpath($strPath);
     }
 
     /* -- Attribute accessors -- */
@@ -182,10 +183,12 @@ abstract class FileSystem {
      * Return the simple boolean attributes for the file or directory denoted
      * by the given abstract pathname, or zero if it does not exist or some
      * other I/O error occurs.
-     * 
+     *
      * @param PhingFile $f
+     * @throws IOException
      */
-    function getBooleanAttributes($f) {
+    public function getBooleanAttributes($f)
+    {
         throw new IOException("getBooleanAttributes() not implemented by fs driver");
     }
 
@@ -196,11 +199,13 @@ abstract class FileSystem {
      * argument is true, then a check for write (not read-write)
      * access is made.  Return false if access is denied or an I/O error
      * occurs.
-     * 
+     *
      * @param PhingFile $f
-     * @param boolean   $write
+     * @param boolean $write
+     * @return bool
      */
-    function checkAccess(PhingFile $f, $write = false) {
+    public function checkAccess(PhingFile $f, $write = false)
+    {
         // we clear stat cache, its expensive to look up from scratch,
         // but we need to be sure
         @clearstatcache();
@@ -228,54 +233,56 @@ abstract class FileSystem {
             return (boolean) @is_writable($strPath);
         }
     }
-    
+
     /**
      * Whether file can be deleted.
-     * @param PhingFile $f
+     * @param  PhingFile $f
      * @return boolean
      */
-    function canDelete(PhingFile $f)
+    public function canDelete(PhingFile $f)
     {
-        clearstatcache(); 
-        $dir = dirname($f->getAbsolutePath()); 
-        return (bool) @is_writable($dir); 
+        clearstatcache();
+        $dir = dirname($f->getAbsolutePath());
+
+        return (bool) @is_writable($dir);
     }
-    
+
     /**
      * Return the time at which the file or directory denoted by the given
      * abstract pathname was last modified, or zero if it does not exist or
      * some other I/O error occurs.
-     * 
-     * @param  PhingFile $f
+     *
+     * @param  PhingFile   $f
      * @return int
      * @throws IOException
      */
-    function getLastModifiedTime(PhingFile $f) {
-        
+    public function getLastModifiedTime(PhingFile $f)
+    {
+
         if (!$f->exists()) {
             return 0;
         }
 
         @clearstatcache();
         $strPath = (string) $f->getPath();
-        
+
         if (@is_link($strPath)) {
             $stats = @lstat($strPath);
-            
+
             if (!isset($stats['mtime'])) {
                 $mtime = false;
             } else {
                 $mtime = $stats['mtime'];
-            } 
+            }
         } else {
             $mtime = @filemtime($strPath);
         }
-            
+
         if (false === $mtime) {
             $msg = "FileSystem::getLastModifiedTime() FAILED. Can not get modified time of $strPath. $php_errormsg";
             throw new IOException($msg);
         }
-            
+
         return (int) $mtime;
     }
 
@@ -283,12 +290,13 @@ abstract class FileSystem {
      * Return the length in bytes of the file denoted by the given abstract
      * pathname, or zero if it does not exist, is a directory, or some other
      * I/O error occurs.
-     * 
-     * @param  PhingFile $f
+     *
+     * @param  PhingFile   $f
      * @throws IOException
      * @return int
      */
-    function getLength(PhingFile $f) {
+    public function getLength(PhingFile $f)
+    {
         $strPath = (string) $f->getAbsolutePath();
         $fs = filesize((string) $strPath);
         if ($fs !== false) {
@@ -307,32 +315,36 @@ abstract class FileSystem {
      * file or directory with the given pathname already exists.  Throw an
      * IOException if an I/O error occurs.
      *
-     * @param  string $strPathname Path of the file to be created.
+     * @param  string      $strPathname Path of the file to be created.
      * @throws IOException
      * @return boolean
      */
-    function createNewFile($strPathname) {
-        if (@file_exists($strPathname))
+    public function createNewFile($strPathname)
+    {
+        if (@file_exists($strPathname)) {
             return false;
-            
+        }
+
         // Create new file
         $fp = @fopen($strPathname, "w");
         if ($fp === false) {
-            throw new IOException("The file \"$strPathname\" could not be created");            
+            throw new IOException("The file \"$strPathname\" could not be created");
         }
-        @fclose($fp);        
+        @fclose($fp);
+
         return true;
     }
 
     /**
      * Delete the file or directory denoted by the given abstract pathname,
      * returning true if and only if the operation succeeds.
-     * 
-     * @param PhingFile $f
-     * @param boolean $recursive
+     *
+     * @param  PhingFile $f
+     * @param  boolean   $recursive
      * @return void
      */
-    function delete(PhingFile $f, $recursive = false) {
+    public function delete(PhingFile $f, $recursive = false)
+    {
         if ($f->isDirectory()) {
             return $this->rmdir($f->getPath(), $recursive);
         } else {
@@ -344,11 +356,12 @@ abstract class FileSystem {
      * Arrange for the file or directory denoted by the given abstract
      * pathname to be deleted when Phing::shutdown is called, returning
      * true if and only if the operation succeeds.
-     * 
-     * @param  PhingFile $f
+     *
+     * @param  PhingFile   $f
      * @throws IOException
      */
-    function deleteOnExit($f) {
+    public function deleteOnExit($f)
+    {
         throw new IOException("deleteOnExit() not implemented by local fs driver");
     }
 
@@ -356,23 +369,26 @@ abstract class FileSystem {
      * List the elements of the directory denoted by the given abstract
      * pathname.  Return an array of strings naming the elements of the
      * directory if successful; otherwise, return <code>null</code>.
-     * 
+     *
      * @param PhingFile $f
+     * @return array
      */
-    function listDir(PhingFile $f) {
+    public function listDir(PhingFile $f)
+    {
         $strPath = (string) $f->getAbsolutePath();
         $d = @dir($strPath);
         if (!$d) {
             return null;
         }
         $list = array();
-        while($entry = $d->read()) {
+        while ($entry = $d->read()) {
             if ($entry != "." && $entry != "..") {
                 array_push($list, $entry);
             }
         }
         $d->close();
         unset($d);
+
         return $list;
     }
 
@@ -381,15 +397,17 @@ abstract class FileSystem {
      * returning true if and only if the operation succeeds.
      *
      * NOTE: umask() is reset to 0 while executing mkdir(), and restored afterwards
-     * 
-     * @param PhingFile $f
-     * @param  int $mode
+     *
+     * @param  PhingFile $f
+     * @param  int       $mode
      * @return boolean
      */
-    function createDirectory(&$f, $mode = 0755) {
+    public function createDirectory(&$f, $mode = 0755)
+    {
         $old_umask = umask(0);
         $return = @mkdir($f->getAbsolutePath(), $mode);
         umask($old_umask);
+
         return $return;
     }
 
@@ -398,12 +416,13 @@ abstract class FileSystem {
      * the second abstract pathname, returning true if and only if
      * the operation succeeds.
      *
-     * @param PhingFile $f1 abstract source file
-     * @param PhingFile $f2 abstract destination file
-     * @return void    
+     * @param  PhingFile   $f1 abstract source file
+     * @param  PhingFile   $f2 abstract destination file
+     * @return void
      * @throws IOException if rename cannot be performed
      */
-    function rename(PhingFile $f1, PhingFile $f2) {        
+    public function rename(PhingFile $f1, PhingFile $f2)
+    {
         // get the canonical paths of the file to rename
         $src = $f1->getAbsolutePath();
         $dest = $f2->getAbsolutePath();
@@ -417,13 +436,14 @@ abstract class FileSystem {
      * Set the last-modified time of the file or directory denoted by the
      * given abstract pathname returning true if and only if the
      * operation succeeds.
-     * 
-     * @param  PhingFile $f
-     * @param  int $time
+     *
+     * @param  PhingFile   $f
+     * @param  int         $time
      * @return void
      * @throws IOException
      */
-    function setLastModifiedTime(PhingFile $f, $time) {        
+    public function setLastModifiedTime(PhingFile $f, $time)
+    {
         $path = $f->getPath();
         $success = @touch($path, $time);
         if (!$success) {
@@ -435,11 +455,12 @@ abstract class FileSystem {
      * Mark the file or directory denoted by the given abstract pathname as
      * read-only, returning <code>true</code> if and only if the operation
      * succeeds.
-     * 
-     * @param  PhingFile $f
+     *
+     * @param  PhingFile   $f
      * @throws IOException
      */
-    function setReadOnly($f) {
+    public function setReadOnly($f)
+    {
         throw new IOException("setReadonly() not implemented by local fs driver");
     }
 
@@ -449,7 +470,8 @@ abstract class FileSystem {
      * List the available filesystem roots, return array of PhingFile objects
      * @throws IOException
      */
-    function listRoots() {
+    public function listRoots()
+    {
         throw new IOException("listRoots() not implemented by local fs driver");
     }
 
@@ -457,32 +479,36 @@ abstract class FileSystem {
 
     /**
      * Compare two abstract pathnames lexicographically.
-     * 
+     *
      * @param PhingFile $f1
      * @param PhingFile $f2
+     * @throws IOException
      */
-    function compare(PhingFile $f1, PhingFile $f2) {
+    public function compare(PhingFile $f1, PhingFile $f2)
+    {
         throw new IOException("compare() not implemented by local fs driver");
     }
 
     /**
      * Copy a file.
      *
-     * @param PhingFile $src Source path and name file to copy.
+     * @param PhingFile $src  Source path and name file to copy.
      * @param PhingFile $dest Destination path and name of new file.
      *
-     * @return void     
+     * @return void
+     *
      * @throws IOException if file cannot be copied.
      */
-    function copy(PhingFile $src, PhingFile $dest) {
+    public function copy(PhingFile $src, PhingFile $dest)
+    {
         global $php_errormsg;
-        
+
         // Recursively copy a directory
-        if($src->isDirectory()) {
+        if ($src->isDirectory()) {
             return $this->copyr($src->getAbsolutePath(), $dest->getAbsolutePath());
         }
-        
-        $srcPath  = $src->getAbsolutePath();
+
+        $srcPath = $src->getAbsolutePath();
         $destPath = $dest->getAbsolutePath();
 
         if (false === @copy($srcPath, $destPath)) { // Copy FAILED. Log and return err.
@@ -490,42 +516,39 @@ abstract class FileSystem {
             $msg = "FileSystem::copy() FAILED. Cannot copy $srcPath to $destPath. $php_errormsg";
             throw new IOException($msg);
         }
-        
-        try {
-            $dest->setMode($src->getMode());
-        } catch(Exception $exc) {
-            // [MA] does chmod returns an error on systems that do not support it ?
-            // eat it up for now.
-        }
+
+        $dest->setMode($src->getMode());
     }
-    
+
     /**
      * Copy a file, or recursively copy a folder and its contents
      *
      * @author      Aidan Lister <aidan@php.net>
      * @version     1.0.1
      * @link        http://aidanlister.com/repos/v/function.copyr.php
-     * @param       string   $source    Source path
-     * @param       string   $dest      Destination path
-     * @return      bool     Returns TRUE on success, FALSE on failure
+     *
+     * @param  string $source Source path
+     * @param  string $dest   Destination path
+     *
+     * @return bool   Returns TRUE on success, FALSE on failure
      */
-    function copyr($source, $dest)
+    public function copyr($source, $dest)
     {
         // Check for symlinks
         if (is_link($source)) {
             return symlink(readlink($source), $dest);
         }
-    
+
         // Simple copy for a file
         if (is_file($source)) {
             return copy($source, $dest);
         }
-    
+
         // Make destination directory
         if (!is_dir($dest)) {
             mkdir($dest);
         }
-    
+
         // Loop through the folder
         $dir = dir($source);
         while (false !== $entry = $dir->read()) {
@@ -533,43 +556,47 @@ abstract class FileSystem {
             if ($entry == '.' || $entry == '..') {
                 continue;
             }
-    
+
             // Deep copy directories
             $this->copyr("$source/$entry", "$dest/$entry");
         }
-    
+
         // Clean up
         $dir->close();
+
         return true;
     }
 
     /**
      * Change the ownership on a file or directory.
      *
-     * @param    string $pathname Path and name of file or directory.
-     * @param    string $user The user name or number of the file or directory. See http://us.php.net/chown
+     * @param string $pathname Path and name of file or directory.
+     * @param string $user     The user name or number of the file or directory. See http://us.php.net/chown
      *
      * @return void
-     * @throws Exception if operation failed.
+     *
+     * @throws IOException if operation failed.
      */
-    function chown($pathname, $user) {
-        if (false === @chown($pathname, $user)) {// FAILED.
+    public function chown($pathname, $user)
+    {
+        if (false === @chown($pathname, $user)) { // FAILED.
             $msg = "FileSystem::chown() FAILED. Cannot chown $pathname. User $user." . (isset($php_errormsg) ? ' ' . $php_errormsg : "");
             throw new IOException($msg);
         }
     }
-    
+
     /**
      * Change the group on a file or directory.
      *
-     * @param  string $pathname Path and name of file or directory.
-     * @param  string $group The group of the file or directory. See http://us.php.net/chgrp
+     * @param string $pathname Path and name of file or directory.
+     * @param string $group    The group of the file or directory. See http://us.php.net/chgrp
      *
      * @return void
      * @throws IOException if operation failed.
      */
-    function chgrp($pathname, $group) {
-        if (false === @chgrp($pathname, $group)) {// FAILED.
+    public function chgrp($pathname, $group)
+    {
+        if (false === @chgrp($pathname, $group)) { // FAILED.
             $msg = "FileSystem::chgrp() FAILED. Cannot chown $pathname. Group $group." . (isset($php_errormsg) ? ' ' . $php_errormsg : "");
             throw new IOException($msg);
         }
@@ -578,17 +605,18 @@ abstract class FileSystem {
     /**
      * Change the permissions on a file or directory.
      *
-     * @param  string $pathname Path and name of file or directory.
-     * @param  int    $mode     The mode (permissions) of the file or
-     *                          directory. If using octal add leading 0. eg. 0777.
-     *                          Mode is affected by the umask system setting.
+     * @param string $pathname Path and name of file or directory.
+     * @param int    $mode     The mode (permissions) of the file or
+     *                         directory. If using octal add leading 0. eg. 0777.
+     *                         Mode is affected by the umask system setting.
      *
-     * @return void     
+     * @return void
      * @throws IOException if operation failed.
      */
-    function chmod($pathname, $mode) {    
-        $str_mode = decoct($mode); // Show octal in messages.    
-        if (false === @chmod($pathname, $mode)) {// FAILED.
+    public function chmod($pathname, $mode)
+    {
+        $str_mode = decoct($mode); // Show octal in messages.
+        if (false === @chmod($pathname, $mode)) { // FAILED.
             $msg = "FileSystem::chmod() FAILED. Cannot chmod $pathname. Mode $str_mode." . (isset($php_errormsg) ? ' ' . $php_errormsg : "");
             throw new IOException($msg);
         }
@@ -596,12 +624,13 @@ abstract class FileSystem {
 
     /**
      * Locks a file and throws an Exception if this is not possible.
-     * 
+     *
      * @param  PhingFile $f
      * @return void
-     * @throws Exception
+     * @throws IOException
      */
-    function lock(PhingFile $f) {
+    public function lock(PhingFile $f)
+    {
         $filename = $f->getPath();
         $fp = @fopen($filename, "w");
         $result = @flock($fp, LOCK_EX);
@@ -618,25 +647,27 @@ abstract class FileSystem {
      * @throws IOException
      * @return void
      */
-    function unlock(PhingFile $f) {
+    public function unlock(PhingFile $f)
+    {
         $filename = $f->getPath();
         $fp = @fopen($filename, "w");
         $result = @flock($fp, LOCK_UN);
         fclose($fp);
         if (!$result) {
-            throw new Exception("Could not unlock file '$filename'");
+            throw new IOException("Could not unlock file '$filename'");
         }
     }
 
     /**
      * Delete a file.
      *
-     * @param  string $file Path and/or name of file to delete.
+     * @param string $file Path and/or name of file to delete.
      *
      * @return void
      * @throws IOException - if an error is encountered.
      */
-    function unlink($file) {
+    public function unlink($file)
+    {
         global $php_errormsg;
         if (false === @unlink($file)) {
             $msg = "FileSystem::unlink() FAILED. Cannot unlink '$file'. $php_errormsg";
@@ -646,15 +677,17 @@ abstract class FileSystem {
 
     /**
      * Symbolically link a file to another name.
-     * 
+     *
      * Currently symlink is not implemented on Windows. Don't use if the application is to be portable.
      *
-     * @param string $target Path and/or name of file to link.
-     * @param string $link Path and/or name of link to be created.
+     * @param  string $target Path and/or name of file to link.
+     * @param  string $link Path and/or name of link to be created.
+     * @throws IOException
      * @return void
      */
-    function symlink($target, $link) {
-    
+    public function symlink($target, $link)
+    {
+
         // If Windows OS then symlink() will report it is not supported in
         // the build. Use this error instead of checking for Windows as the OS.
 
@@ -669,13 +702,15 @@ abstract class FileSystem {
     /**
      * Set the modification and access time on a file to the present time.
      *
-     * @param string $file Path and/or name of file to touch.
-     * @param int $time 
+     * @param  string $file Path and/or name of file to touch.
+     * @param  int $time
+     * @throws Exception
      * @return void
      */
-    function touch($file, $time = null) {
+    public function touch($file, $time = null)
+    {
         global $php_errormsg;
-        
+
         if (null === $time) {
             $error = @touch($file);
         } else {
@@ -684,39 +719,42 @@ abstract class FileSystem {
 
         if (false === $error) { // FAILED.
             // Add error from php to end of log message. $php_errormsg.
-            $msg = "FileSystem::touch() FAILED. Cannot touch '$file'. $php_errormsg";            
-            throw new Exception($msg);            
+            $msg = "FileSystem::touch() FAILED. Cannot touch '$file'. $php_errormsg";
+            throw new Exception($msg);
         }
     }
 
     /**
      * Delete an empty directory OR a directory and all of its contents.
      *
-     * @param    dir    String. Path and/or name of directory to delete.
-     * @param    children    Boolean.    False: don't delete directory contents.
-     *                                    True: delete directory contents.
+     * @param string $dir Path and/or name of directory to delete.
+     * @param bool $children     False: don't delete directory contents.
+     *                           True: delete directory contents.
+     *
+     * @throws Exception
      *
      * @return void
      */
-    function rmdir($dir, $children = false) {
+    public function rmdir($dir, $children = false)
+    {
         global $php_errormsg;
-        
+
         // If children=FALSE only delete dir if empty.
         if (false === $children) {
-        
+
             if (false === @rmdir($dir)) { // FAILED.
                 // Add error from php to end of log message. $php_errormsg.
                 $msg = "FileSystem::rmdir() FAILED. Cannot rmdir $dir. $php_errormsg";
                 throw new Exception($msg);
             }
-            
+
         } else { // delete contents and dir.
 
             $handle = @opendir($dir);
 
             if (false === $handle) { // Error.
 
-                $msg = "FileSystem::rmdir() FAILED. Cannot opendir() $dir. $php_errormsg";                
+                $msg = "FileSystem::rmdir() FAILED. Cannot opendir() $dir. $php_errormsg";
                 throw new Exception($msg);
 
             } else { // Read from handle.
@@ -730,7 +768,7 @@ abstract class FileSystem {
                         // This ONLY serves the purpose of making the Logger
                         // output look nice:)
 
-                        if (strpos(strrev($dir), DIRECTORY_SEPARATOR) === 0) {// there is a /
+                        if (strpos(strrev($dir), DIRECTORY_SEPARATOR) === 0) { // there is a /
                             $next_entry = $dir . $entry;
                         } else { // no /
                             $next_entry = $dir . DIRECTORY_SEPARATOR . $entry;
@@ -741,20 +779,22 @@ abstract class FileSystem {
 
                         // Don't error on is_dir()
                         if (false == @is_dir($next_entry)) { // Is file.
-                            
+
                             try {
                                 self::unlink($next_entry); // Delete.
-                            } catch (Exception $e) {                            
-                                $msg = "FileSystem::Rmdir() FAILED. Cannot FileSystem::Unlink() $next_entry. ". $e->getMessage();
+                            } catch (Exception $e) {
+                                $msg = "FileSystem::Rmdir() FAILED. Cannot FileSystem::Unlink() $next_entry. " . $e->getMessage(
+                                    );
                                 throw new Exception($msg);
                             }
 
                         } else { // Is directory.
-                            
+
                             try {
                                 self::rmdir($next_entry, true); // Delete
                             } catch (Exception $e) {
-                                $msg = "FileSystem::rmdir() FAILED. Cannot FileSystem::rmdir() $next_entry. ". $e->getMessage();
+                                $msg = "FileSystem::rmdir() FAILED. Cannot FileSystem::rmdir() $next_entry. " . $e->getMessage(
+                                    );
                                 throw new Exception($msg);
                             }
 
@@ -765,33 +805,35 @@ abstract class FileSystem {
 
             // Don't error on closedir()
             @closedir($handle);
-            
+
             if (false === @rmdir($dir)) { // FAILED.
                 // Add error from php to end of log message. $php_errormsg.
                 $msg = "FileSystem::rmdir() FAILED. Cannot rmdir $dir. $php_errormsg";
                 throw new Exception($msg);
             }
-            
+
         }
-                
+
     }
 
     /**
      * Set the umask for file and directory creation.
      *
-     * @param    mode    Int. Permissions ususally in ocatal. Use leading 0 for
+     * @param Int $mode
+     * @throws Exception
+     * @internal param Int $mode . Permissions usually in ocatal. Use leading 0 for
      *                    octal. Number between 0 and 0777.
      *
      * @return void
-     * @throws Exception if there is an error performing operation.     
      */
-    function umask($mode) {
+    public function umask($mode)
+    {
         global $php_errormsg;
-        
+
         // CONSIDERME:
         // Throw a warning if mode is 0. PHP converts illegal octal numbers to
         // 0 so 0 might not be what the user intended.
-                        
+
         $str_mode = decoct($mode); // Show octal in messages.
 
         if (false === @umask($mode)) { // FAILED.
@@ -804,30 +846,31 @@ abstract class FileSystem {
     /**
      * Compare the modified time of two files.
      *
-     * @param    file1    String. Path and name of file1.
-     * @param    file2    String. Path and name of file2.
+     * @param string $file1 Path and name of file1.
+     * @param string $file2 Path and name of file2.
+     *
+     * @return int  1 if file1 is newer.
+     *              -1 if file2 is newer.
+     *              0 if files have the same time.
+     *              Err object on failure.
      *
-     * @return    Int.     1 if file1 is newer.
-     *                 -1 if file2 is newer.
-     *                  0 if files have the same time.
-     *                  Err object on failure.
-     *     
      * @throws Exception - if cannot get modified time of either file.
      */
-    function compareMTimes($file1, $file2) {
+    public function compareMTimes($file1, $file2)
+    {
 
         $mtime1 = filemtime($file1);
         $mtime2 = filemtime($file2);
 
-        if ($mtime1 === false) { // FAILED. Log and return err.        
+        if ($mtime1 === false) { // FAILED. Log and return err.
             // Add error from php to end of log message. $php_errormsg.
             $msg = "FileSystem::compareMTimes() FAILED. Cannot can not get modified time of $file1.";
-            throw new Exception($msg);            
+            throw new Exception($msg);
         } elseif ($mtime2 === false) { // FAILED. Log and return err.
             // Add error from php to end of log message. $php_errormsg.
             $msg = "FileSystem::compareMTimes() FAILED. Cannot can not get modified time of $file2.";
             throw new Exception($msg);
-        } else { // Worked. Log and return compare.                
+        } else { // Worked. Log and return compare.
             // Compare mtimes.
             if ($mtime1 == $mtime2) {
                 return 0;
@@ -836,5 +879,4 @@ abstract class FileSystem {
             } // end compare
         }
     }
-        
 }
