@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 553b6c3f96f78c68a753a8c9b0483f197df21bfd $
+ *  $Id: 1ef78a7a6b9b116ebb4ec53c39f716f3ce1877e7 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -630,7 +630,7 @@ class Win32FileSystem extends FileSystem
      */
     private function fixEncoding($strPath)
     {
-        $codepage = 'Windows-' . trim(strstr(setlocale(LC_CTYPE, 0), '.'), '.');
+        $codepage = 'CP' . trim(strstr(setlocale(LC_CTYPE, ''), '.'), '.');
         if (function_exists('iconv')) {
             $strPath = iconv('UTF-8', $codepage . '//IGNORE', $strPath);
         } elseif (function_exists('mb_convert_encoding')) {
