@@ -1,7 +1,7 @@
 <?php
 
 /*
- *  $Id: 774d989f0f224564952ea51682006030b243ea9c $
+ *  $Id: 04cb8e6079c1dd642f942085dafad99da004190d $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -88,6 +88,13 @@ class SymlinkTask extends Task
      */
     private $_overwrite = false;
 
+    /**
+     * Whether to create relative symlinks
+     *
+     * @var boolean
+     */
+    private $relative = false;
+
     /**
      * setter for _target
      *
@@ -133,6 +140,14 @@ class SymlinkTask extends Task
         $this->_overwrite = $overwrite;
     }
 
+    /**
+     * @param boolean $relative
+     */
+    public function setRelative($relative)
+    {
+        $this->relative = $relative;
+    }
+
     /**
      * getter for _target
      *
@@ -183,6 +198,14 @@ class SymlinkTask extends Task
         return $this->_overwrite;
     }
 
+    /**
+     * @return boolean
+     */
+    public function isRelative()
+    {
+        return $this->relative;
+    }
+
     /**
      * Generates an array of directories / files to be linked
      * If _filesets is empty, returns getTarget()
@@ -212,7 +235,11 @@ class SymlinkTask extends Task
                 throw new BuildException('Link must be an existing directory when using fileset');
             }
 
-            $fromDir = $fs->getDir($this->getProject())->getAbsolutePath();
+            if ($this->isRelative()) {
+                $fromDir = $fs->getDir($this->getProject())->getPath();
+            } else {
+                $fromDir = $fs->getDir($this->getProject())->getAbsolutePath();
+            }
 
             if (!is_dir($fromDir)) {
                 $this->log('Directory doesn\'t exist: ' . $fromDir, Project::MSG_WARN);
