@@ -24,7 +24,7 @@ require_once 'phing/tasks/ext/ExtractBaseTask.php';
  * Extracts one or several tar archives using PEAR Archive_Tar
  *
  * @author    Joakim Bodin <joakim.bodin+phing@gmail.com>
- * @version   $Id: fc8e1f42f6edd1c730d83a34d6b39f9ac7e4310d $
+ * @version   $Id: a7c20154729a165ba27135dfc3db76a96a11908b $
  * @package   phing.tasks.ext
  * @since     2.2.0
  */
@@ -70,7 +70,7 @@ class UntarTask extends ExtractBaseTask
         try {
             $tar = $this->initTar($tarfile);
             if (!$tar->extractModify($this->todir->getAbsolutePath(), $this->removepath, $this->preservePermissions)) {
-                throw new BuildException('Failed to extract tar file: ' . $tarfile->getAbsolutePath());
+                throw new BuildException('Failed to extract tar file: ' . $tarfile->getAbsolutePath() . '. Error: ' . $tar->error_object->getMessage());
             }
         } catch (IOException $ioe) {
             $msg = "Could not extract tar file: " . $ioe->getMessage();
