@@ -1,6 +1,6 @@
 <?php
 /**
- * $Id: 2f73afc3401097333c7f187eacb79de9e16a6f35 $
+ * $Id: 9a15437e8ba7eb26f59aa20fd6c10e682b26e697 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -30,7 +30,7 @@ require_once 'phing/tasks/ext/coverage/CoverageReportTransformer.php';
  * Transforms information in a code coverage database to XML
  *
  * @author Michiel Rook <mrook@php.net>
- * @version $Id: 2f73afc3401097333c7f187eacb79de9e16a6f35 $
+ * @version $Id: 9a15437e8ba7eb26f59aa20fd6c10e682b26e697 $
  * @package phing.tasks.ext.coverage
  * @since 2.1.0
  */
@@ -374,7 +374,7 @@ class CoverageReportTask extends Task
 
                 if ($subpackageName !== null) {
                     $this->addSubpackageToPackage($packageName, $subpackageName);
-                    $this->addClassToSubpackage($className, $classElement);
+                    $this->addClassToSubpackage($reflection->getName(), $classElement);
                 } else {
                     $this->addClassToPackage($packageName, $classElement);
                 }
