@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 95b6bc9543e4a1917767a9fe0103dbd9c1668192 $
+ *  $Id: 8b23ec7a8c95625a37c67d7cba50df578b95b2b6 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -27,7 +27,7 @@ require_once 'phing/tasks/ext/git/GitBaseTask.php';
  *
  * @author Evan Kaufman <evan@digitalflophouse.com>
  * @author Victor Farazdagi <simple.square@gmail.com>
- * @version $Id: 95b6bc9543e4a1917767a9fe0103dbd9c1668192 $
+ * @version $Id: 8b23ec7a8c95625a37c67d7cba50df578b95b2b6 $
  * @package phing.tasks.ext.git
  * @see VersionControl_Git
  * @since 2.4.5
@@ -74,13 +74,13 @@ class GitLogTask extends GitBaseTask
      * <since> argument to git-log
      * @var string
      */
-    private $sinceCommit;
+    private $since;
 
     /**
      * <until> argument to git-log
      * @var string
      */
-    private $untilCommit = 'HEAD';
+    private $until;
 
     /**
      * <path> arguments to git-log
@@ -123,7 +123,10 @@ class GitLogTask extends GitBaseTask
         if (null !== $this->getSince()) {
             $command->setOption('since', $this->getSince());
         }
-        $command->setOption('until', $this->getUntil());
+        
+        if (null !== $this->getUntil()) {
+            $command->setOption('until', $this->getUntil());
+        }
 
         $command->addDoubleDash(true);
         if (null !== $this->getPaths()) {
@@ -270,7 +273,7 @@ class GitLogTask extends GitBaseTask
      */
     public function setSince($since)
     {
-        $this->sinceCommit = $since;
+        $this->since = $since;
     }
 
     /**
@@ -278,7 +281,7 @@ class GitLogTask extends GitBaseTask
      */
     public function getSince()
     {
-        return $this->sinceCommit;
+        return $this->since;
     }
 
     /**
@@ -294,7 +297,7 @@ class GitLogTask extends GitBaseTask
      */
     public function setUntil($until)
     {
-        $this->untilCommit = $until;
+        $this->until = $until;
     }
 
     /**
@@ -302,7 +305,7 @@ class GitLogTask extends GitBaseTask
      */
     public function getUntil()
     {
-        return $this->untilCommit;
+        return $this->until;
     }
 
     /**
