@@ -1,6 +1,6 @@
 <?php
 /**
- * $Id: 7184c30b7252a939bc6a3b8b7e59b412fa244625 $
+ * $Id: 8db5f2b968a9a111de7bbd1f1ddbc9f5a3c9d55a $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -30,7 +30,7 @@ require_once 'phing/tasks/ext/phpunit/FormatterElement.php';
  * Runs PHPUnit tests.
  *
  * @author Michiel Rook <mrook@php.net>
- * @version $Id: 7184c30b7252a939bc6a3b8b7e59b412fa244625 $
+ * @version $Id: 8db5f2b968a9a111de7bbd1f1ddbc9f5a3c9d55a $
  * @package phing.tasks.ext.phpunit
  * @see BatchTest
  * @since 2.1.0
@@ -481,11 +481,22 @@ class PHPUnitTask extends Task
             $pwd = dirname(__FILE__);
             $path = realpath($pwd . '/../../../');
 
-            $filter = new PHP_CodeCoverage_Filter();
+            if (class_exists('PHP_CodeCoverage_Filter')) {
+                $filter = new PHP_CodeCoverage_Filter();
+            } elseif (class_exists('\SebastianBergmann\CodeCoverage\Filter')) {
+                $filterClass = '\SebastianBergmann\CodeCoverage\Filter';
+                $filter = new $filterClass;
+            }
             if (method_exists($filter, 'addDirectoryToBlacklist')) {
                 $filter->addDirectoryToBlacklist($path);
             }
-            $runner->setCodecoverage(new PHP_CodeCoverage(null, $filter));
+            if (class_exists('PHP_CodeCoverage')) {
+                $codeCokverage = new PHP_CodeCoverage(null, $filter);
+            } elseif (class_exists('\SebastianBergmann\CodeCoverage\CodeCoverage')) {
+                $codeCokverageClass = '\SebastianBergmann\CodeCoverage\CodeCoverage';
+                $codeCokverage = new $codeCokverageClass(null, $filter);
+            }
+            $runner->setCodecoverage($codeCokverage);
         }
 
         $runner->setUseCustomErrorHandler($this->usecustomerrorhandler);
