@@ -1,6 +1,6 @@
 <?php
 /**
- * $Id: 07b0bdd8f6adb167b753d21663c339565e807e70 $
+ * $Id: 6ac25b4744ffc88118865a46b54b34923bd4b94a $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -25,7 +25,7 @@ require_once 'phing/tasks/ext/phpunit/formatter/PHPUnitResultFormatter.php';
  * Prints Clover XML output of the test
  *
  * @author Michiel Rook <mrook@php.net>
- * @version $Id: 07b0bdd8f6adb167b753d21663c339565e807e70 $
+ * @version $Id: 6ac25b4744ffc88118865a46b54b34923bd4b94a $
  * @package phing.tasks.ext.formatter
  * @since 2.4.0
  */
@@ -81,7 +81,12 @@ class CloverPHPUnitResultFormatter extends PHPUnitResultFormatter
         $coverage = $this->result->getCodeCoverage();
 
         if (!empty($coverage)) {
-            $clover = new PHP_CodeCoverage_Report_Clover();
+            if (class_exists('PHP_CodeCoverage_Report_Clover')) {
+                $clover = new PHP_CodeCoverage_Report_Clover();
+            } elseif (class_exists('\SebastianBergmann\CodeCoverage\Report\Clover')) {
+                $cloverClass = '\SebastianBergmann\CodeCoverage\Report\Clover';
+                $clover = new $cloverClass;
+            }
 
             $contents = $clover->process($coverage);
 
