@@ -1,6 +1,6 @@
 <?php
 /**
- * $Id: 77309ab0270c91d4263ad82de3fba36f1eeb804b $
+ * $Id: eec7114955b928683994705ad4dc68fe246ef23f $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -26,7 +26,7 @@ require_once 'phing/tasks/ext/svn/SvnBaseTask.php';
  * Commits changes in a local working copy to the repository
  *
  * @author Johan Persson <johanp@aditus.nu>
- * @version $Id: 77309ab0270c91d4263ad82de3fba36f1eeb804b $
+ * @version $Id: eec7114955b928683994705ad4dc68fe246ef23f $
  * @package phing.tasks.ext.svn
  * @since 2.4.0
  */
@@ -39,7 +39,7 @@ class SvnCommitTask extends SvnBaseTask
 
     /**
      * Property name where we store the revision number of the just
-     * commited version.
+     * committed version.
      */
     private $propertyName = "svn.committedrevision";
 
@@ -91,7 +91,7 @@ class SvnCommitTask extends SvnBaseTask
         $this->setup('commit');
 
         $this->log(
-            "Commiting SVN working copy at '" . $this->getWorkingCopy() . "' with message '" . $this->GetMessage() . "'"
+            "Committing SVN working copy at '" . $this->getWorkingCopy() . "' with message '" . $this->GetMessage() . "'"
         );
 
         $output = $this->run(array(), array('message' => $this->GetMessage()));
