@@ -1,7 +1,7 @@
 <?php
 
 /*
- *  $Id: eca2f1475da5e3a296736a5eefc44a1184f49f63 $
+ *  $Id: e25b4d62e56e9dad7e7e776ef7214a9557e0f18d $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -30,7 +30,7 @@ include_once 'phing/system/io/FileParserFactory.php';
  *
  * @author    Andreas Aderhold <andi@binarycloud.com>
  * @author    Hans Lellelid <hans@xmpl.org>
- * @version   $Id: eca2f1475da5e3a296736a5eefc44a1184f49f63 $
+ * @version   $Id: e25b4d62e56e9dad7e7e776ef7214a9557e0f18d $
  * @package   phing.tasks.system
  */
 class PropertyTask extends Task
@@ -329,8 +329,10 @@ class PropertyTask extends Task
 
                 if ($referencedObject instanceof Exception) {
                     $reference = $referencedObject->getMessage();
-                } else {
+                } elseif (method_exists($referencedObject, 'toString')) {
                     $reference = $referencedObject->toString();
+                } else {
+                    $reference = (string) $referencedObject;
                 }
 
                 $this->addProperty($this->name, $reference);
@@ -340,8 +342,10 @@ class PropertyTask extends Task
 
                     if ($referencedObject instanceof Exception) {
                         $reference = $referencedObject->getMessage();
-                    } else {
+                    } elseif (method_exists($referencedObject, 'toString')) {
                         $reference = $referencedObject->toString();
+                    } else {
+                        $reference = (string) $referencedObject;
                     }
                     $this->addProperty($this->name, $reference);
                 } else {
