@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 02ac32dcbb53394d677a9ee39479f3b427306896 $
+ *  $Id: e185e05826c5bf6bd0fac6652f483c67548095c6 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -28,7 +28,7 @@ require_once 'phing/Task.php';
  * Based on Ant's Tstamp task.
  *
  * @author   Michiel Rook <mrook@php.net>
- * @version  $Id: 02ac32dcbb53394d677a9ee39479f3b427306896 $
+ * @version  $Id: e185e05826c5bf6bd0fac6652f483c67548095c6 $
  * @package  phing.tasks.system
  * @since    2.2.0
  */
@@ -104,6 +104,7 @@ class TstampCustomFormat
     private $propertyName = "";
     private $pattern = "";
     private $locale = "";
+    private $timezone = "";
 
     /**
      * The property to receive the date/time string in the given pattern
@@ -136,6 +137,14 @@ class TstampCustomFormat
         $this->locale = $locale;
     }
 
+    /**
+     * @param string $timezone
+     */
+    public function setTimezone($timezone)
+    {
+        $this->timezone = $timezone;
+    }
+
     /**
      * validate parameter and execute the format.
      *
@@ -152,16 +161,27 @@ class TstampCustomFormat
             throw new BuildException("pattern attribute must be provided");
         }
 
+        $oldlocale = "";
         if (!empty($this->locale)) {
+            $oldlocale = setlocale(LC_ALL, 0);
             setlocale(LC_ALL, $this->locale);
         }
 
+        $savedTimezone = date_default_timezone_get();
+        if (!empty($this->timezone)) {
+            date_default_timezone_set($this->timezone);
+        }
+
         $value = strftime($this->pattern);
         $tstamp->prefixProperty($this->propertyName, $value);
 
         if (!empty($this->locale)) {
             // reset locale
-            setlocale(LC_ALL, null);
+            setlocale(LC_ALL, $oldlocale);
+        }
+
+        if (!empty($this->timezone)) {
+            date_default_timezone_set($savedTimezone);
         }
     }
 }
