@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: a2207ec35496db9f3ad2a15a780bb2ec26cf04f0 $
+ * $Id: 139b0653bc863b536f2a2f488238c4e702c00c71 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -20,6 +20,7 @@
  */
 
 require_once 'phing/Task.php';
+require_once 'phing/tasks/system/condition/ConditionBase.php';
 
 /**
  *  Based on Apache Ant Wait For:
@@ -40,7 +41,7 @@ require_once 'phing/Task.php';
  *  limitations under the License.
  *
  * @author    Michiel Rook <mrook@php.net>
- * @version   $Id: a2207ec35496db9f3ad2a15a780bb2ec26cf04f0 $
+ * @version   $Id: 139b0653bc863b536f2a2f488238c4e702c00c71 $
  * @package   phing.tasks.system
  */
 class WaitForTask extends ConditionBase
@@ -63,6 +64,11 @@ class WaitForTask extends ConditionBase
 
     protected $timeoutProperty = null;
 
+    public function __construct($taskName = 'waitfor')
+    {
+        parent::__construct($taskName);
+    }
+
     /**
      * Set the maximum length of time to wait.
      * @param int $maxWait
@@ -182,15 +188,24 @@ class WaitForTask extends ConditionBase
 
         while (microtime(true) * 1000 < $end) {
             if ($condition->evaluate()) {
-                $this->log("waitfor: condition was met", Project::MSG_VERBOSE);
-
+                $this->processSuccess();
                 return;
             }
 
             usleep($checkEveryMillis * 1000);
         }
 
-        $this->log("waitfor: timeout", Project::MSG_VERBOSE);
+        $this->processTimeout();
+    }
+
+    protected function processSuccess()
+    {
+        $this->log($this->getTaskName() . ": condition was met", Project::MSG_VERBOSE);
+    }
+
+    protected function processTimeout()
+    {
+        $this->log($this->getTaskName() . ": timeout", Project::MSG_VERBOSE);
 
         if ($this->timeoutProperty != null) {
             $this->project->setNewProperty($this->timeoutProperty, "true");
