@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 0df7e2e9aeb1d0ee94e2ead72891b5342ae13af8 $
+ *  $Id: b120ee679285146acd231a143251a1678db95566 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -35,6 +35,7 @@ include_once 'phing/types/selectors/ContainsRegexpSelector.php';
 include_once 'phing/types/selectors/DateSelector.php';
 include_once 'phing/types/selectors/DependSelector.php';
 include_once 'phing/types/selectors/DepthSelector.php';
+include_once 'phing/types/selectors/DifferentSelector.php';
 include_once 'phing/types/selectors/ExtendSelector.php';
 include_once 'phing/types/selectors/FilenameSelector.php';
 include_once 'phing/types/selectors/MajoritySelector.php';
@@ -64,7 +65,7 @@ include_once 'phing/util/DirectoryScanner.php';
  *
  * @author    Andreas Aderhold <andi@binarycloud.com>
  * @author    Hans Lellelid <hans@xmpl.org>
- * @version    $Id: 0df7e2e9aeb1d0ee94e2ead72891b5342ae13af8 $
+ * @version    $Id: b120ee679285146acd231a143251a1678db95566 $
  * @see        ProjectComponent
  * @package    phing.types
  */
@@ -737,4 +738,15 @@ class AbstractFileSet extends DataType implements SelectorContainer
 
         return $o;
     }
+
+    /**
+     * add a different selector entry on the selector list
+     */
+    public function createDifferent()
+    {
+        $o = new DifferentSelector();
+        $this->appendSelector($o);
+
+        return $o;
+    }
 }
