@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 5e241ade627fda421a9722279f0930fed97a7ddf $
+ *  $Id: b070eed1e9ac42f7ebd826ff7f3081f45e7c944d $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -27,7 +27,7 @@ include_once 'phing/types/DataType.php';
  * for the patternset stuff.
  *
  * @author   Andreas Aderhold, andi@binarycloud.com
- * @version  $Id: 5e241ade627fda421a9722279f0930fed97a7ddf $
+ * @version  $Id: b070eed1e9ac42f7ebd826ff7f3081f45e7c944d $
  * @package  phing.types
  */
 class PatternSet extends DataType
@@ -239,7 +239,7 @@ class PatternSet extends DataType
             }
 
         } catch (IOException $ioe) {
-            $msg = "An error occured while reading from pattern file: " . $patternfile->__toString();
+            $msg = "An error occurred while reading from pattern file: " . $patternfile->__toString();
             if ($patternReader) {
                 $patternReader->close();
             }
