@@ -1,7 +1,7 @@
 <?php
 
 /*
- * $Id: eb9a1bff3c3a35a383e003cae076c0ca3e0d8ac7 $
+ * $Id: 5d7d39fd94f07bb38f7bf01212ea7e845cb5858d $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -37,6 +37,8 @@ class ContainsSelector extends BaseExtendSelector
     private $casesensitive = true;
     const CONTAINS_KEY = "text";
     const CASE_KEY = "casesensitive";
+    const WHITESPACE_KEY = "ignorewhitespace";
+    private $ignorewhitespace = false;
 
     /**
      * @return string
@@ -51,6 +53,12 @@ class ContainsSelector extends BaseExtendSelector
         } else {
             $buf .= "false";
         }
+        $buf .= " ignorewhitespace: ";
+        if ($this->ignorewhitespace) {
+            $buf .= "true";
+        } else {
+            $buf .= "false";
+        }
         $buf .= "}";
 
         return $buf;
@@ -76,6 +84,14 @@ class ContainsSelector extends BaseExtendSelector
         $this->casesensitive = $casesensitive;
     }
 
+    /**
+     * @param boolean $ignoreWhitespace
+     */
+    public function setIgnoreWhitespace($ignoreWhitespace)
+    {
+        $this->ignorewhitespace = $ignoreWhitespace;
+    }
+
     /**
      * When using this as a custom selector, this method will be called.
      * It translates each parameter into the appropriate setXXX() call.
@@ -96,6 +112,9 @@ class ContainsSelector extends BaseExtendSelector
                     case self::CASE_KEY:
                         $this->setCasesensitive($parameters[$i]->getValue());
                         break;
+                    case self::WHITESPACE_KEY:
+                        $this->setIgnoreWhitespace($parameters[$i]->getValue());
+                        break;
                     default:
                         $this->setError("Invalid parameter " . $paramname);
                 }
@@ -144,6 +163,9 @@ class ContainsSelector extends BaseExtendSelector
         if (!$this->casesensitive) {
             $userstr = strtolower($this->contains);
         }
+        if ($this->ignorewhitespace) {
+            $userstr = SelectorUtils::removeWhitespace($userstr);
+        }
 
         $in = null;
         try {
@@ -153,6 +175,9 @@ class ContainsSelector extends BaseExtendSelector
                 if (!$this->casesensitive) {
                     $teststr = strtolower($teststr);
                 }
+                if ($this->ignorewhitespace) {
+                    $teststr = SelectorUtils::removeWhitespace($teststr);
+                }
                 if (strpos($teststr, $userstr) !== false) {
                     return true;
                 }
