@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: cc81e1eb8ef44a36e9fcc01ff1ce3acc8933f3f3 $
+ *  $Id: 90512f0542e101f1d60b89c2c9d77da1dd90137f $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -110,7 +110,7 @@ include_once 'phing/types/selectors/SelectorUtils.php';
  * @author   Magesh Umasankar, umagesh@rediffmail.com
  * @author   Andreas Aderhold, andi@binarycloud.com
  *
- * @version   $Id: cc81e1eb8ef44a36e9fcc01ff1ce3acc8933f3f3 $
+ * @version   $Id: 90512f0542e101f1d60b89c2c9d77da1dd90137f $
  * @package   phing.util
  */
 class DirectoryScanner implements SelectorScanner
@@ -139,6 +139,15 @@ class DirectoryScanner implements SelectorScanner
         "**/.gitattributes",
         "**/.gitignore",
         "**/.gitmodules",
+        "**/.hg",
+        "**/.hg/**",
+        "**/.hgignore",
+        "**/.hgsub",
+        "**/.hgsubstate",
+        "**/.hgtags",
+        "**/.bzr",
+        "**/.bzr/**",
+        "**/.bzrignore",
     );
 
     /** The base directory which should be scanned. */
