@@ -8,7 +8,7 @@
  * @package  phing.util
  * @author   Christian Weiske <cweiske@cweiske.de>
  * @license  LGPL v3 or later http://www.gnu.org/licenses/lgpl.html
- * @version  SVN: $Id: 439ffcc0d1099571cd299fcebeec55c98e4a6b71 $
+ * @version  SVN: $Id: 36ea68a722ee20d394476949c62c276bb45cd316 $
  * @link     http://www.phing.info/
  */
 require_once 'phing/util/DirectoryScanner.php';
@@ -187,7 +187,7 @@ class PearPackageScanner extends DirectoryScanner
             $pkg = new PEAR_PackageFile($config);
             $packageInfo = $pkg->fromPackageFile($this->packageFile, PEAR_VALIDATE_NORMAL);
             PEAR::staticPopErrorHandling();
-            if (PEAR::isError($packageInfo)) {
+            if (@PEAR::isError($packageInfo)) {
                 throw new BuildException("Errors in package file: " . $packageInfo->getMessage());
             }
         }
