@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 529b5cbd1cece30a29edd41d1d014a48d64b47c7 $
+ *  $Id: fcea2d1ae635e834c061996c46d721b780532ed9 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -49,6 +49,12 @@ class PregEngine implements RegexpEngine
      */
     private $modifiers = null;
 
+    /**
+     * Set the limit.
+     * @var int
+     */
+    private $limit = -1;
+
     /**
      * Pattern delimiter.
      */
@@ -126,6 +132,24 @@ class PregEngine implements RegexpEngine
         return $this->multiline;
     }
 
+    /**
+     * Sets the maximum possible replacements for each pattern.
+     * @param int $limit
+     */
+    public function setLimit($limit)
+    {
+        $this->limit = $limit;
+    }
+
+    /**
+     * Returns the maximum possible replacements for each pattern.
+     * @return int
+     */
+    public function getLimit()
+    {
+        return $this->limit;
+    }
+
     /**
      * The pattern needs to be converted into PREG style -- which includes adding expression delims & any flags, etc.
      * @param  string $pattern
@@ -193,7 +217,7 @@ class PregEngine implements RegexpEngine
         // but PREG prefers $1 syntax.
         $replace = preg_replace('/\\\(\d+)/', '\$$1', $replace);
 
-        return preg_replace($this->preparePattern($pattern), $replace, $source);
+        return preg_replace($this->preparePattern($pattern), $replace, $source, $this->limit);
     }
 
 }
