@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: d2bfdbbcbc1f6e4b02c9c8796b476db46ee35728 $
+ *  $Id: ad952b68b1876f57f4854621cfed990abb7fa310 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -23,7 +23,7 @@
  * A factory class for regex functions.
  * @author Hans Lellelid <hans@xmpl.org>
  * @package  phing.util.regexp
- * @version $Id: d2bfdbbcbc1f6e4b02c9c8796b476db46ee35728 $
+ * @version $Id: ad952b68b1876f57f4854621cfed990abb7fa310 $
  */
 class Regexp
 {
@@ -56,7 +56,6 @@ class Regexp
      * Constructor sets the regex engine to use (preg by default).
      * @param string $engineType
      * @throws BuildException
-     * @internal param string $_engineType The regex engine to use.
      */
     public function __construct($engineType = 'preg')
     {
@@ -218,4 +217,13 @@ class Regexp
     {
         return $this->engine->getMultiline();
     }
+
+    /**
+     * Sets the maximum possible replacements for each pattern.
+     * @param int $limit
+     */
+    public function setLimit($limit)
+    {
+        $this->engine->setLimit($limit);
+    }
 }
